The Chancery Division is one of three divisions of the High Court. It handles a wide range of civil cases including business disputes, intellectual property and probate issues. It has various lists that deal with specialist issues such as the Business List, Insolvency and Companies List, Intellectual Property List, or Property, Trusts and Probate List. It contains the Intellectual Property Enterprise and Patents Courts.

This court began to regularly transfer judgments to The National Archives in 2022. The oldest judgment from this court included in Find Case Law is from {start_year}.

You can read more about it on [the chancery division on the Judiciary website](https://www.judiciary.uk/courts-and-tribunals/business-and-property-courts/chancery-division/){target="\_blank"}.
